%%
%% This is file `t1enc-antomega.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% antenc.dtx  (with options: `T1')
%% 
%% This file is a part of the ANTOMEGA project version 0.8
%% -----------------------------------------------------
%% 
%% It may be distributed under the terms of the LaTeX Project Public
%% License, as described in lppl.txt in the base LaTeX distribution.
%% Either version 1.0 or, at your option, any later version.
%% Copyright (C) 2001 -- 2005 by Alexej Kryukov
%% Please report errors to: A.M. Kryukov <basileia@yandex.ru>
%% 
\NeedsTeXFormat{LaTeX2e}
\ProvidesFile{t1enc-antomega.def}
  [2005/05/07 v0.8 Antomega encodings definition file]
\DeclareFontEncoding{T1}{}{}
\def\ant@encoding{T1}
\DeclareTextCommand{\`}{\ant@encoding}[1]{#1^^^^0300}
\DeclareTextCommand{\'}{\ant@encoding}[1]{#1^^^^0301}
\DeclareTextCommand{\^}{\ant@encoding}[1]{#1^^^^0302}
\DeclareTextCommand{\~}{\ant@encoding}[1]{#1^^^^0303}
\DeclareTextCommand{\"}{\ant@encoding}[1]{#1^^^^0308}
\DeclareTextCommand{\H}{\ant@encoding}[1]{#1^^^^030b}
\DeclareTextCommand{\r}{\ant@encoding}[1]{#1^^^^030a}
\DeclareTextCommand{\v}{\ant@encoding}[1]{#1^^^^030c}
\DeclareTextCommand{\u}{\ant@encoding}[1]{#1^^^^0306}
\DeclareTextCommand{\=}{\ant@encoding}[1]{#1^^^^0304}
\DeclareTextCommand{\.}{\ant@encoding}[1]{#1^^^^0307}
\DeclareTextCommand{\b}{\ant@encoding}[1]{#1^^^^0331}
\DeclareTextCommand{\c}{\ant@encoding}[1]{#1^^^^0327}
\DeclareTextCommand{\d}{\ant@encoding}[1]{#1^^^^0323}
\DeclareTextCommand{\k}{\ant@encoding}[1]{#1^^^^0328}
\DeclareTextAccent{\GraveAccent}{\ant@encoding}{0}
\DeclareTextAccent{\AcuteAccent}{\ant@encoding}{1}
\DeclareTextAccent{\CircumflexAccent}{\ant@encoding}{2}
\DeclareTextAccent{\TildeAccent}{\ant@encoding}{3}
\DeclareTextAccent{\DieresisAccent}{\ant@encoding}{4}
\DeclareTextAccent{\HungarumlautAccent}{\ant@encoding}{5}
\DeclareTextAccent{\RingAccent}{\ant@encoding}{6}
\DeclareTextAccent{\CaronAccent}{\ant@encoding}{7}
\DeclareTextAccent{\BreveAccent}{\ant@encoding}{8}
\DeclareTextAccent{\MacronAccent}{\ant@encoding}{9}
\DeclareTextAccent{\DotAboveAccent}{\ant@encoding}{10}
\DeclareTextCommand{\BarBelowAccent}{\ant@encoding}[1]
   {\hmode@bgroup\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\noocpchar{9}}\vss}\hidewidth}\egroup}
\DeclareTextCommand{\CedillaAccent}{\ant@encoding}[1]
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent11 #1%
     \else{\ooalign{\hidewidth\noocpchar{11}\hidewidth
        \crcr\unhbox\z@}}\fi}
\DeclareTextCommand{\DotBelowAccent}{\ant@encoding}[1]
   {\hmode@bgroup
    \o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}\egroup}
\DeclareTextCommand{\OgonekAccent}{\ant@encoding}[1]
   {\oalign{\null#1\crcr\hidewidth\noocpchar{12}}}
\DeclareTextCommand{\textdollar}{\ant@encoding}{\noocpchar{"24}}
\DeclareTextCommand{\textgreater}{\ant@encoding}{\noocpchar{"3C}}
\DeclareTextCommand{\textless}{\ant@encoding}{\noocpchar{"3E}}
\DeclareTextCommand{\textbackslash}{\ant@encoding}{\noocpchar{"5C}}
\DeclareTextCommand{\textasciicircum}{\ant@encoding}{\noocpchar{"5E}}
\DeclareTextCommand{\textunderscore}{\ant@encoding}{\noocpchar{"5F}}
\DeclareTextCommand{\textasciigrave}{\ant@encoding}{\noocpchar{"60}}
\DeclareTextCommand{\textbraceleft}{\ant@encoding}{\noocpchar{"7B}}
\DeclareTextCommand{\textbar}{\ant@encoding}{\noocpchar{"7C}}
\DeclareTextCommand{\textbraceright}{\ant@encoding}{\noocpchar{"7D}}
\DeclareTextCommand{\textasciitilde}{\ant@encoding}{\noocpchar{"7E}}
\DeclareTextSymbol{\textexclamdown}{\ant@encoding}{"00A1}
\DeclareTextSymbol{\textsterling}{\ant@encoding}{"00A3}
\DeclareTextSymbol{\textsection}{\ant@encoding}{"00A7}
\DeclareTextSymbol{\guillemotleft}{\ant@encoding}{"00AB}
\DeclareTextSymbol{\guillemotright}{\ant@encoding}{"00BB}
\DeclareTextSymbol{\textquestiondown}{\ant@encoding}{"00BF}
\DeclareTextComposite{\`}{\ant@encoding}{A}{"00C0}
\DeclareTextComposite{\'}{\ant@encoding}{A}{"00C1}
\DeclareTextComposite{\^}{\ant@encoding}{A}{"00C2}
\DeclareTextComposite{\~}{\ant@encoding}{A}{"00C3}
\DeclareTextComposite{\"}{\ant@encoding}{A}{"00C4}
\DeclareTextComposite{\r}{\ant@encoding}{A}{"00C5}
\DeclareTextSymbol{\AE}{\ant@encoding}{"00C6}
\DeclareTextComposite{\c}{\ant@encoding}{C}{"00C7}
\DeclareTextComposite{\`}{\ant@encoding}{E}{"00C8}
\DeclareTextComposite{\'}{\ant@encoding}{E}{"00C9}
\DeclareTextComposite{\^}{\ant@encoding}{E}{"00CA}
\DeclareTextComposite{\"}{\ant@encoding}{E}{"00CB}
\DeclareTextComposite{\`}{\ant@encoding}{I}{"00CC}
\DeclareTextComposite{\'}{\ant@encoding}{I}{"00CD}
\DeclareTextComposite{\^}{\ant@encoding}{I}{"00CE}
\DeclareTextComposite{\"}{\ant@encoding}{I}{"00CF}
\DeclareTextSymbol{\DH}{\ant@encoding}{"00D0}
\DeclareTextComposite{\~}{\ant@encoding}{N}{"00D1}
\DeclareTextComposite{\`}{\ant@encoding}{O}{"00D2}
\DeclareTextComposite{\'}{\ant@encoding}{O}{"00D3}
\DeclareTextComposite{\^}{\ant@encoding}{O}{"00D4}
\DeclareTextComposite{\~}{\ant@encoding}{O}{"00D5}
\DeclareTextComposite{\"}{\ant@encoding}{O}{"00D6}
\DeclareTextSymbol{\texttimes}{\ant@encoding}{"00D7}
\DeclareTextSymbol{\O}{\ant@encoding}{"00D8}
\DeclareTextComposite{\`}{\ant@encoding}{U}{"00D9}
\DeclareTextComposite{\'}{\ant@encoding}{U}{"00DA}
\DeclareTextComposite{\^}{\ant@encoding}{U}{"00DB}
\DeclareTextComposite{\"}{\ant@encoding}{U}{"00DC}
\DeclareTextComposite{\'}{\ant@encoding}{Y}{"00DD}
\DeclareTextSymbol{\TH}{\ant@encoding}{"00DE}
\DeclareTextCommand{\SS}{\ant@encoding}{SS}
\DeclareTextSymbol{\ss}{\ant@encoding}{"00DF}
\DeclareTextComposite{\`}{\ant@encoding}{a}{"00E0}
\DeclareTextComposite{\'}{\ant@encoding}{a}{"00E1}
\DeclareTextComposite{\^}{\ant@encoding}{a}{"00E2}
\DeclareTextComposite{\~}{\ant@encoding}{a}{"00E3}
\DeclareTextComposite{\"}{\ant@encoding}{a}{"00E4}
\DeclareTextComposite{\r}{\ant@encoding}{a}{"00E5}
\DeclareTextComposite{\c}{\ant@encoding}{c}{"00E7}
\DeclareTextSymbol{\ae}{\ant@encoding}{"00E6}
\DeclareTextComposite{\`}{\ant@encoding}{e}{"00E8}
\DeclareTextComposite{\'}{\ant@encoding}{e}{"00E9}
\DeclareTextComposite{\^}{\ant@encoding}{e}{"00EA}
\DeclareTextComposite{\"}{\ant@encoding}{e}{"00EB}
\DeclareTextComposite{\`}{\ant@encoding}{i}{"00EC}
\DeclareTextComposite{\`}{\ant@encoding}{\i}{"00EC}
\DeclareTextComposite{\'}{\ant@encoding}{i}{"00ED}
\DeclareTextComposite{\'}{\ant@encoding}{\i}{"00ED}
\DeclareTextComposite{\^}{\ant@encoding}{i}{"00EE}
\DeclareTextComposite{\^}{\ant@encoding}{\i}{"00EE}
\DeclareTextComposite{\"}{\ant@encoding}{i}{"00EF}
\DeclareTextComposite{\"}{\ant@encoding}{\i}{"00EF}
\DeclareTextSymbol{\dh}{\ant@encoding}{"00F0}
\DeclareTextComposite{\~}{\ant@encoding}{n}{"00F1}
\DeclareTextComposite{\`}{\ant@encoding}{o}{"00F2}
\DeclareTextComposite{\'}{\ant@encoding}{o}{"00F3}
\DeclareTextComposite{\^}{\ant@encoding}{o}{"00F4}
\DeclareTextComposite{\~}{\ant@encoding}{o}{"00F5}
\DeclareTextComposite{\"}{\ant@encoding}{o}{"00F6}
\DeclareTextSymbol{\textdiv}{\ant@encoding}{"00F7}
\DeclareTextSymbol{\o}{\ant@encoding}{"00F8}
\DeclareTextComposite{\`}{\ant@encoding}{u}{"00F9}
\DeclareTextComposite{\'}{\ant@encoding}{u}{"00FA}
\DeclareTextComposite{\^}{\ant@encoding}{u}{"00FB}
\DeclareTextComposite{\"}{\ant@encoding}{u}{"00FC}
\DeclareTextComposite{\'}{\ant@encoding}{y}{"00FD}
\DeclareTextSymbol{\th}{\ant@encoding}{"00FE}
\DeclareTextComposite{\"}{\ant@encoding}{y}{"00FF}
\DeclareTextComposite{\u}{\ant@encoding}{A}{"0102}
\DeclareTextComposite{\u}{\ant@encoding}{a}{"0103}
\DeclareTextComposite{\k}{\ant@encoding}{A}{"0104}
\DeclareTextComposite{\k}{\ant@encoding}{a}{"0105}
\DeclareTextComposite{\'}{\ant@encoding}{C}{"0106}
\DeclareTextComposite{\'}{\ant@encoding}{c}{"0107}
\DeclareTextComposite{\v}{\ant@encoding}{C}{"0108}
\DeclareTextComposite{\v}{\ant@encoding}{c}{"0109}
\DeclareTextComposite{\v}{\ant@encoding}{D}{"010E}
\DeclareTextComposite{\v}{\ant@encoding}{d}{"010F}
\DeclareTextSymbol{\DJ}{\ant@encoding}{"0110}
\DeclareTextSymbol{\dj}{\ant@encoding}{"0111}
\DeclareTextComposite{\k}{\ant@encoding}{E}{"0118}
\DeclareTextComposite{\k}{\ant@encoding}{e}{"0119}
\DeclareTextComposite{\v}{\ant@encoding}{E}{"011A}
\DeclareTextComposite{\v}{\ant@encoding}{e}{"011B}
\DeclareTextComposite{\u}{\ant@encoding}{G}{"011E}
\DeclareTextComposite{\u}{\ant@encoding}{g}{"011F}
\DeclareTextComposite{\.}{\ant@encoding}{I}{"0130}
\DeclareTextSymbol{\i}{\ant@encoding}{"0131}
\DeclareTextSymbol{\IJ}{\ant@encoding}{"0132}
\DeclareTextSymbol{\ij}{\ant@encoding}{"0133}
\DeclareTextComposite{\'}{\ant@encoding}{L}{"0139}
\DeclareTextComposite{\'}{\ant@encoding}{l}{"013A}
\DeclareTextComposite{\v}{\ant@encoding}{L}{"013D}
\DeclareTextComposite{\v}{\ant@encoding}{l}{"013E}
\DeclareTextSymbol{\L}{\ant@encoding}{"0141}
\DeclareTextSymbol{\l}{\ant@encoding}{"0142}
\DeclareTextComposite{\'}{\ant@encoding}{N}{"0143}
\DeclareTextComposite{\'}{\ant@encoding}{n}{"0144}
\DeclareTextComposite{\v}{\ant@encoding}{N}{"0147}
\DeclareTextComposite{\v}{\ant@encoding}{n}{"0148}
\DeclareTextSymbol{\NG}{\ant@encoding}{"014A}
\DeclareTextSymbol{\ng}{\ant@encoding}{"014B}
\DeclareTextComposite{\H}{\ant@encoding}{O}{"0150}
\DeclareTextComposite{\H}{\ant@encoding}{o}{"0151}
\DeclareTextSymbol{\OE}{\ant@encoding}{"0152}
\DeclareTextSymbol{\oe}{\ant@encoding}{"0153}
\DeclareTextComposite{\'}{\ant@encoding}{R}{"0154}
\DeclareTextComposite{\'}{\ant@encoding}{r}{"0155}
\DeclareTextComposite{\v}{\ant@encoding}{R}{"0158}
\DeclareTextComposite{\v}{\ant@encoding}{r}{"0159}
\DeclareTextComposite{\'}{\ant@encoding}{S}{"015A}
\DeclareTextComposite{\'}{\ant@encoding}{s}{"015B}
\DeclareTextComposite{\c}{\ant@encoding}{S}{"015E}
\DeclareTextComposite{\c}{\ant@encoding}{s}{"015F}
\DeclareTextComposite{\v}{\ant@encoding}{S}{"0160}
\DeclareTextComposite{\v}{\ant@encoding}{s}{"0161}
\DeclareTextComposite{\c}{\ant@encoding}{T}{"0162}
\DeclareTextComposite{\c}{\ant@encoding}{t}{"0163}
\DeclareTextComposite{\v}{\ant@encoding}{T}{"0164}
\DeclareTextComposite{\v}{\ant@encoding}{t}{"0165}
\DeclareTextComposite{\H}{\ant@encoding}{U}{"0170}
\DeclareTextComposite{\H}{\ant@encoding}{u}{"0171}
\DeclareTextComposite{\"}{\ant@encoding}{Y}{"0178}
\DeclareTextComposite{\'}{\ant@encoding}{Z}{"0179}
\DeclareTextComposite{\'}{\ant@encoding}{z}{"017A}
\DeclareTextComposite{\.}{\ant@encoding}{Z}{"017B}
\DeclareTextComposite{\.}{\ant@encoding}{z}{"017C}
\DeclareTextComposite{\v}{\ant@encoding}{Z}{"017D}
\DeclareTextComposite{\v}{\ant@encoding}{z}{"017E}
\DeclareTextSymbol{\textcompwordmark}{\ant@encoding}{"200C}
\DeclareTextSymbol{\guilsinglleft}{\ant@encoding}{"2039}
\DeclareTextSymbol{\guilsinglright}{\ant@encoding}{"203A}
\DeclareTextSymbol{\textendash}{\ant@encoding}{"2013}
\DeclareTextSymbol{\textemdash}{\ant@encoding}{"2014}
\DeclareTextSymbol{\textquoteleft}{\ant@encoding}{"2018}
\DeclareTextSymbol{\textquoteright}{\ant@encoding}{"2019}
\DeclareTextSymbol{\quotesinglbase}{\ant@encoding}{"201A}
\DeclareTextSymbol{\textquotedblleft}{\ant@encoding}{"201C}
\DeclareTextSymbol{\textquotedblright}{\ant@encoding}{"201D}
\DeclareTextSymbol{\quotedblbase}{\ant@encoding}{"201E}
\DeclareTextCommand{\textcircled}{\ant@encoding}[1]{{%
   \ooalign{%
      \hfil \raise .07ex\hbox {\upshape#1}\hfil \crcr
      \char 79   % '117 = "4F
   }%
}}
\DeclareTextSymbol{\textvisiblespace}{\ant@encoding}{"2423}
\DeclareTextSymbol{\j}{\ant@encoding}{"F6BE}
\let\ant@encoding\@undefined
\endinput
%%
%% End of file `t1enc-antomega.def'.
